@@ -17,12 +17,6 @@ pub fn e_num(item: TokenStream) -> TokenStream {
                 self as usize
             }
         }
-
-        impl From<#impl_ident> for usize {
-            fn from(self) -> #impl_ident {
-
-            }
-        }
     }
     .into()
 }
